@@ -5,6 +5,8 @@ use comrak::{markdown_to_html, ComrakOptions};
 pub fn plugin() -> Plugin {
 	Box::new(|mut ir: RefIR| {
 		info!("Starting Markdown processing");
+		let mut markdown_options = ComrakOptions::default();
+		markdown_options.render.unsafe_ = true;
 		let files = ir.files.clone();
 		let markdown_files = files.iter().filter(|(p, _)| match p.extension() {
 			Some(ext) => ext == "md",
@@ -20,7 +22,7 @@ pub fn plugin() -> Plugin {
 				ShFile {
 					content: markdown_to_html(
 						std::str::from_utf8(&file.content).unwrap(),
-						&ComrakOptions::default(),
+						&markdown_options,
 					)
 					.into(),
 					frontmatter: file.frontmatter.clone(),
